import 'package:flutter/material.dart';

import 'package:minehunter/entities/cell.dart';
import 'package:minehunter/provider/data.dart';

class Board {
  static Container buildGameBoard(Data myProvider) {
    return Container(
      margin: const EdgeInsets.all(2),
      padding: const EdgeInsets.all(2),
      child: Column(
        children: [
          buildGameTileset(myProvider),
        ],
      ),
    );
  }

  static Widget buildGameTileset(Data myProvider) {
    List<List<Cell>> cells = myProvider.cells;
    Color borderColor = myProvider.reportMode ? Colors.blue : Colors.black;

    return Container(
      decoration: BoxDecoration(
        color: borderColor,
        borderRadius: BorderRadius.circular(2),
        border: Border.all(
          color: borderColor,
          width: 2,
        ),
      ),
      child: Table(
        defaultColumnWidth: const IntrinsicColumnWidth(),
        children: [
          for (int row = 0; row < myProvider.sizeVertical; row++)
            TableRow(
              children: [
                for (int col = 0; col < myProvider.sizeHorizontal; col++)
                  Column(
                    children: [
                      cells[row][col].widget(myProvider, row, col),
                    ],
                  ),
              ],
            ),
        ],
      ),
    );
  }

  static TextButton buildWalkIndicator(Data myProvider) {
    String reportModeSuffix = myProvider.reportMode ? 'off' : 'on';

    return TextButton(
      child: Image(
        image: AssetImage(
            'assets/skins/${myProvider.parameterSkin}_indicator_walk_$reportModeSuffix.png'),
        fit: BoxFit.fill,
      ),
      onPressed: () => myProvider.updateReportMode(false),
    );
  }

  static TextButton buildReportIndicator(Data myProvider) {
    String reportModeSuffix = myProvider.reportMode ? 'on' : 'off';

    return TextButton(
      child: Image(
        image: AssetImage(
            'assets/skins/${myProvider.parameterSkin}_indicator_report_$reportModeSuffix.png'),
        fit: BoxFit.fill,
      ),
      onPressed: () => myProvider.updateReportMode(true),
    );
  }

  static TextButton buildToggleFlagModeButton(Data myProvider) {
    String reportModeSuffix = myProvider.reportMode ? 'on' : 'off';

    return TextButton(
      child: Image(
        image: AssetImage(
            'assets/skins/${myProvider.parameterSkin}_button_mark_mine_$reportModeSuffix.png'),
        fit: BoxFit.fill,
      ),
      onPressed: () => myProvider.updateReportMode(!myProvider.reportMode),
    );
  }

  static Widget buildToggleFlagModeLayout(Data myProvider) {
    Image paddingBlock = Image(
      image: AssetImage('assets/skins/${myProvider.parameterSkin}_empty.png'),
      fit: BoxFit.fill,
    );

    return Table(
      defaultColumnWidth: const IntrinsicColumnWidth(),
      children: [
        TableRow(
          children: [
            TableCell(child: paddingBlock),
            TableCell(child: buildWalkIndicator(myProvider)),
            TableCell(child: buildToggleFlagModeButton(myProvider)),
            TableCell(child: buildReportIndicator(myProvider)),
            TableCell(child: paddingBlock),
          ],
        ),
      ],
    );
  }
}
